Stan Math Library: stan/math/fwd/scal/fun/exp2.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

exp2.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_EXP2_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_EXP2_HPP
3
4 #include <stan/math/fwd/core.hpp>
5 #include <stan/math/prim/scal/fun/exp2.hpp>
6 #include <stan/math/prim/scal/fun/constants.hpp>
7 #include <cmath>
8
9 namespace stan {
10 namespace math {
11
12 template <typename T>
13 inline fvar<T>
14 exp2(const fvar<T>& x) {
15 using stan::math::exp2;
16 using std::log;
17 return fvar<T>(exp2(x.val_), x.d_ * exp2(x.val_) * stan::math::LOG_2);
18 }
19
20 }
21 }
22 #endif
stan::math::LOG_2
const double LOG_2
The natural logarithm of 2, .
Definition: constants.hpp:33
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan
Definition: log_sum_exp.hpp:8
stan::math::log
fvar< T > log(const fvar< T > &x)
Definition: log.hpp:15
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::exp2
fvar< T > exp2(const fvar< T > &x)
Definition: exp2.hpp:14
constants.hpp
exp2.hpp
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.